@@ -19,7 +19,8 @@ pymysql.install_as_MySQLdb()
 
 
 class ForApp():
-    def __init__(self, import_name, MONGO_HOST_URL, secret_key, log_folder=None, root_path=None):
+    def __init__(self, import_name, MONGO_HOST_URL, secret_key, log_folder=None, root_path=None,
+                 need_before_request=True):
         self.import_name = import_name
         self.log_folder = log_folder
 
@@ -50,41 +51,43 @@ class ForApp():
 
         Session(app)
 
-        @app.before_request
-        def before_request():
-            g.request_start_time = datetime.datetime.now()
-            ForLog.show("g.request_start_time", g.request_start_time)
-            # request.json 只能够接受方法为POST、Body为raw，header 内容为 application/json类型的数据：
-            # print(request.json if request.method == "POST" else request.args)
-            params = {}
-            params = request.json if request.method in [
-                "POST", "PUT"] else request.args
-            if g.params is None and request.method == 'POST' and request.files:
-                params = request.form
+        if need_before_request:
+            @app.before_request
+            def before_request():
+                g.request_start_time = datetime.datetime.now()
+                ForLog.show("g.request_start_time", g.request_start_time)
+                # request.json 只能够接受方法为POST、Body为raw，header 内容为 application/json类型的数据：
+                # print(request.json if request.method == "POST" else request.args)
+                params = request.json if request.method.upper() in [
+                    "POST", "PUT"] else request.args
+                if params is None and request.method == 'POST' and request.files:
+                    params = request.form
 
-            # if request.args:
-            #     params.update(request.args.to_dict(flat=True))
-            # if request.method != 'GET' and request.json:
-            #     if type(request.json) == type([]):
-            #         for x in request.json:
-            #             params.update(x)
-            #     else:
-            #         params.update(request.json)
-            # if request.form:
-            #     params.update(request.form.to_dict(flat=True))
-            if request.content_type == "application/json":
-                params.update(request.json)
-            g.params = params
-            ip = request.remote_addr
-            # print("请求头",request.headers)
-            try:
-                _ip = request.headers["X-Real-IP"]
-                if _ip is not None:
-                    ip = _ip
-            except Exception as e:
-                pass
-            g.ip = ip
-            g.error = False
+                # if request.args:
+                #     params.update(request.args.to_dict(flat=True))
+                # if request.method != 'GET' and request.json:
+                #     if type(request.json) == type([]):
+                #         for x in request.json:
+                #             params.update(x)
+                #     else:
+                #         params.update(request.json)
+                # if request.form:
+                #     params.update(request.form.to_dict(flat=True))
+                if params is None:
+                    params = {}
+                if request.content_type == "application/json":
+                    params.update(request.json)
+                g.params = params
+                ip = request.remote_addr
+                # print("请求头",request.headers)
+                try:
+                    _ip = request.headers["X-Real-IP"]
+                    if _ip is not None:
+                        ip = _ip
+                except Exception as e:
+                    pass
+                g.ip = ip
+                g.error = False
 
         @app.after_request
         def after_request(response):
